import { Temporal } from "temporal-polyfill"
import { cloneDeep } from "lodash-es"
import { fakeServerState } from "@/fakeServerState"

export interface TypeOfTea {
	id: string
	name: string
	steepingTime: Temporal.Duration
	registrationTimestamp: Temporal.Instant
}

export interface SteepingTimeChange {
	id: string
	typeOfTeaId: string
	timestamp: Temporal.Instant
	newValue: Temporal.Duration
}

export interface BrewingEvent {
	id: string
	typeOfTeaId: string
	timestamp: Temporal.Instant
}

export interface Configuration {
	defaultSteepingTime: Temporal.Duration
	feedbackTimeout: Temporal.Duration
}

const delay = () => new Promise(resolve => setTimeout(resolve, 1000))

export async function fetchConfiguration(): Promise<Configuration> {
	await delay()
	return cloneDeep(fakeServerState.configuration)
}

export async function updateConfiguration(value: Configuration) {
	await delay()
	fakeServerState.configuration = cloneDeep(value)
}

export async function fetchBrewingEvents(): Promise<BrewingEvent[]> {
	await delay()
	return cloneDeep(fakeServerState.brewingEvents)
}

export async function fetchTypesOfTeaById(): Promise<Map<string, TypeOfTea>> {
	await delay()
	return new Map(fakeServerState.typesOfTea.map(t => [t.id, t]))
}

export async function updateTypeOfTea(id: string, data: Pick<TypeOfTea, "name" | "steepingTime">) {
	await delay()
	Object.assign(fakeServerState.typesOfTea.find(t => t.id === id)!, data)
}